@@ -160,10 +160,14 @@ half-hour the rest of the week, use the period
 
 =head1 VERSION
 
-1.21
+1.22
 
 =head1 HISTORY
 
+        Version 1.22
+        ------------
+                - Fixed tests
+
         Version 1.21
         ------------
                 - Bug fix: Stopped using $' and $`.
@@ -190,7 +194,9 @@ half-hour the rest of the week, use the period
 
 =head1 AUTHOR
 
-Patrick Ryan <pgryan@geocities.com>
+Patrick Ryan <perl@pryan.org> wrote it.
+
+Paul Boyd <pboyd@cpan.org> fixed a bug and wrote some tests.
 
 =head1 COPYRIGHT
 
@@ -198,16 +204,6 @@ Copyright (c) 1997 Patrick Ryan.  All rights reserved.  This Perl module
 uses the conditions given by Perl.  This module may only be distributed
 and or modified under the conditions given by Perl.
 
-=head1 DATE
-
-January 16th, 2011
-
-=head1 SOURCE
-
-This distribution can be found at
-
-	http://www.perl.com/CPAN/modules/by-module/Time/
-
 =cut
 
 package Time::Period;
@@ -217,7 +213,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(inPeriod);
 
-$VERSION = "1.21";
+$VERSION = "1.22";
 
 sub inPeriod {
 
